breed [ agents agent ]

agents-own
[
  index                                   ;; id of agent in group defining position
  alpha
  beta
  x                                       ;; investment level
  newx 
  share                                   ;; share of common resource
  wealth
  wealth-avg-g                            ;; average wealth for current generational period
  success                                 ;; seasonal success - sufficient resource received for the cycle - agent's average number of successful cycles in current generation
]

patches-own
[
  n-members                               ;; group size
  members                                 ;; list of turtles who are members of group
  pwealth                                 ;; total wealth of agents on patch
  pginix                                  ;; gini of investment on patch
  pginishare                              ;; gini of shares from the common resources
  px
  cpr
  no-war?
  game
  gini-x                                   ;; group gini-coefficient for contributions
  gini-share                               ;; group gini-coefficient for shares
]

globals
[
  num-groups                               ;; number of groups
  total-population                         ;; total population of agents
  max-cpr
  max-wealth   
  chi
  possible-x                               ;; possible decisions to invest in public infrastructure
  possible-y                               ;; possible shares to extract from common resources
  gen                                      ;; which generation
  games                                    ;; number of games played
  
  cum-a                                    ;; cumulated values of parameters during last 100 ticks of the simulation
  cum-b
  cum-x
  cum-y
  cum-share
  cum-wealth
  cum-cpr
  first-cum-share
  second-cum-share
  mid-cum-share
  second-last-cum-share
  last-cum-share
  first-cum-x
  second-cum-x
  mid-cum-x
  second-last-cum-x
  last-cum-x
  
  avg-a                                    ;; avg a for all agents
  avg-b                                    ;; avg b  "   "   "
  avg-x
  avg-share                                ;; avg y  "   "   "
  avg-wealth
  avg-cpr
  avg-success
  
  avg-gini-x
  avg-gini-share
  interval-gini-x
  interval-gini-share
  
  first-share                              ;; avg shares received by agents according to position in their respective patch
  second-share
  mid-share
  second-last-share
  last-share
  
  first-x                                  ;; avg investment level by agents according to their position in their respective patch
  second-x
  mid-x
  second-last-x
  last-x
  
  first-a
  second-a
  mid-a
  second-last-a
  last-a
  
  first-b
  second-b
  mid-b
  second-last-b
  last-b
]

;; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 

to setup
  clear-all
  set num-groups ( world-height * world-width )
  set total-population ( num-groups * group-size )
  set-default-shape agents "circle"
  create-agents total-population
  set chi 0.5
  set possible-x ( list 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1 )
  set possible-y ( list 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1 )

  set cum-a 0
  set cum-b 0
  set cum-x 0
  set cum-y 0
  set cum-share 0
  set cum-wealth 0
  set cum-cpr 0
  set first-cum-share 0
  set second-cum-share 0
  set mid-cum-share 0
  set second-last-cum-share 0
  set last-cum-share 0
  set first-cum-x 0
  set second-cum-x 0
  set mid-cum-x 0
  set second-last-cum-x 0
  set last-cum-x 0
  
  set avg-a 0
  set avg-b 0
  set avg-x 0
  set avg-share 0
  set avg-wealth 0
  set avg-cpr 0
  
  set first-share 0
  set second-share 0
  set mid-share 0
  set second-last-share 0
  set last-share 0
  
  set first-x 0
  set second-x 0
  set mid-x 0
  set second-last-x 0
  set last-x 0
  
  if output-file?
  [
    if output-filename = "null" or output-filename = ""
      [ set output-filename "irrigation-output.csv" ]
  
    ifelse file-exists? output-filename
    [
      file-open output-filename
    ]
    [
      file-open output-filename
      file-print "ticks,min-units,alpha,beta,x,y,wealth,cpr,gini-x,gini-share,first-x,second-x,mid-x,second-last-x,last-x,first-share,second-share,mid-share,second-last-share,last-share,first-a,second-a,mid-a,second-last-a,last-a,first-b,second-b,mid-b,second-last-b,last-b,cpr-gamma,cpr-r,eta,ex,generation-cycle,group-size,mu,regard-floor"
    ]
    file-flush
  ]
  
  ask patches ; initialize each patch
  [
    set n-members 0
    set members [ ]
    set pwealth 0
    set px 0
    set cpr 0
    set no-war? true
    set pcolor 60
    set game 0 ; if 0 then linear PG if 1 asymmetric game
  ]
  
  ask agents ; populate each patch with five agents
  [
    set index 0
    set success 0
    set alpha 0
    set beta 0
    
    set x random-float 1    
    
    set size 0.1
    set color 12
    
    let bool false
    while [ bool = false ]
    [
      setxy random-pxcor random-pycor
      if [n-members] of patch xcor ycor < group-size ;; only consider patches that do have less than group-size number of agents
      [
        set bool true
        let thismember self
        ask patch xcor ycor [set n-members n-members + 1]
        ask thismember [set index [n-members] of patch xcor ycor]                                             ;; set agent's position in patch - if assigned patch has 0 agents, current agent will become first agent in the patch (index: 1) ...
        ask patch xcor ycor [set members fput thismember members]                                             ;; and finally add this agent to the patch's [members] list
      ]
    ]
  ]
  
  ask patches
  [
    let sum-x 0
    foreach reverse members
    [                                                                            
      set sum-x sum-x + [x] of ?
      
      ask ?
      [
        if [index] of ? = 1 [ setxy ( xcor - 0.25 ) ( ycor + 0.25 ) ]
        if [index] of ? = 2 [ setxy ( xcor + 0.25 ) ( ycor + 0.25 ) ]
        if ( [index] of ? = ( group-size - 1 ) and group-size > 3 ) [ setxy ( xcor - 0.25 ) ( ycor - 0.25 ) ]
        if ( [index] of ? = ( group-size ) and group-size > 4 ) [ setxy ( xcor + 0.25 ) ( ycor - 0.25 ) ]
      ]
    ]
    
    set cpr ( calc-cpr sum-x cpr-r cpr-gamma group-size game)                 
    set pwealth process-shares                                             
  ]
  
  set max-cpr ( calc-cpr group-size cpr-r cpr-gamma group-size 1)           
  set max-wealth ( ( 0.2 * group-size ) + ( calc-cpr ( 0.8 * group-size ) cpr-r cpr-gamma group-size 1 ) )   
  setup-plot
end

to go
  ; every tick is a generation in which "generation-cycle" number of games are played by each group
  let i 0
  set games []
  while [i < generation-cycle]
  [
      set games lput 0 games
      set i i + 1
  ]

  set i 0
  while [i < freqassym]
  [
    let teller random generation-cycle
    if item teller games = 0 [
      set games replace-item teller games 1
      set i i + 1
    ]
  ]
  
  set i 0
  ask patches [ set pwealth 0 set pginix 0 set pginishare 0]

  ask agents [ set wealth-avg-g 0 set success 0]

  set gen 0

  while [ gen < generation-cycle ]     ;; all agents play the game for "generation-cycle" times of rounds before earnings define next generation           
  [
    calc-wealth  ;; agents play the games and derive income
    calc-gini
    set gen gen + 1
  ]
  
  set avg-gini-x 0
  set avg-gini-share 0
  ask patches
  [
    set pwealth ( pwealth / generation-cycle )
    set pginix ( pginix / generation-cycle )        
    set pginishare (pginishare / generation-cycle)
    set avg-gini-x avg-gini-x + pginix
    set avg-gini-share avg-gini-share + pginishare
  ]
  
  set avg-gini-x ( avg-gini-x / num-groups )
  set avg-gini-share (avg-gini-share / num-groups)
  ask agents
  [
    set wealth-avg-g ( wealth-avg-g / generation-cycle )
  ]
  
  do-imitations
  do-conflict
  do-mutations
  
  tick
  
  if enable-plots? [ calculate-stats ]
  if enable-plots? [ do-plot ]
  if output-file? [ do-data-output ]
end


to calc-wealth
  ask patches
  [
    let x-list [ ]                                 ;; list of xs from last time step
    let y-list [ ]                                 ;; list of shares from last time step
    let wealth-list [ ]
    let sum-x 0
    set game item gen games 

    foreach reverse members
    [
      set x-list fput [x] of ? x-list
      ifelse game = 1 [
      ifelse cpr > 0
        [ set y-list fput [share] of ? y-list ]
        [ set y-list fput 0 y-list ] 
      ][
        ifelse cpr > 0 
        [set y-list fput 0.2 y-list]
        [set y-list fput 0 y-list]
      ]                                            
    ]                                                                            
    
    foreach reverse members                       ;; agents are activated in the order in which they have access to the common resource
    [
      let member-index [index] of ?
      let member-a [alpha] of ?
      let member-b [beta] of ?
      let u-list [ ]
      let u-sum 0                                                                
      foreach possible-x   ;; first determine the expected wealth for different investment levels assuming that others make the same decisions as in the previous round
      [                                                                         
        let e-sum-x 0
        let i group-size
        foreach x-list
        [
          if i != member-index
          [
            set e-sum-x e-sum-x + ?
          ]
          set i i - 1
        ]
        set e-sum-x e-sum-x + ?                                                  
        let e-cpr ( calc-cpr e-sum-x cpr-r cpr-gamma group-size game)                
              
        set wealth-list [ ]
        set i 1                                          
        while [ i <= group-size ]
        [
          ifelse i != member-index
            [ set wealth-list fput ( ( 1 - ( item ( group-size - i ) x-list ) ) + ( ( item ( group-size - i ) y-list ) * e-cpr ) ) wealth-list ]
            [ set wealth-list fput ( ( 1 - ? ) + ( ( item ( group-size - i ) y-list ) * e-cpr ) ) wealth-list ]
          set i i + 1
        ]                                                                       
                                                                                                                                                                                                                                          
        let uwealth calc-uwealth group-size member-index wealth-list            
        
        set u-list fput ( calc-utility uwealth member-a member-b ) u-list            ;; calculate the utility value for this possible-x and the estimated wealth values
        if first u-list > 0 [set u-sum u-sum + ( exp (first u-list * eta ))]         ;; add this utility value to a utility-sum for probabilistic choice algorithm
      ]                                                                         
      
      let p-list get-plist u-list u-sum                                        
      
      let i 1
      let x-found? false
      let rand random-float 1                                                 
      let running-p 0
      while [ i <= length p-list and x-found? = false ]
      [
        set running-p running-p + ( item ( length p-list - i ) p-list )
        ifelse ( rand < running-p )
          [ set x-found? true ]
          [ set i i + 1 ]
      ] 
      ask ? [set newx item (i - 1) possible-x]  
      set sum-x sum-x + [newx] of ?                                                
    ]                                                                          
    foreach members [ask ? [set x newx]]
    set px sum-x
    set cpr ( calc-cpr px cpr-r cpr-gamma group-size game)                       
    set pwealth ( pwealth + process-shares )                                    
  ]
end

;; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

to-report calc-cpr [ sumx r gamma gsize typegame]     ;; This procedure calculate the common resource of the group dependent on the group investment
    ifelse typegame = 1 [
      let calcpg 0
      ifelse sumx < 1.0 [set calcpg 0 ][
        ifelse sumx < 1.5 [set calcpg 0.5][
          ifelse sumx < 2.0 [set calcpg 2.0][
            ifelse sumx < 2.5 [set calcpg 4.0][
              ifelse sumx < 3.0 [set calcpg 6.0][
                ifelse sumx < 3.5 [set calcpg 7.5][
                  ifelse sumx < 4.0 [set calcpg 8.5][
                    ifelse sumx < 4.5 [set calcpg 9.5][set calcpg 10.0]]]]]]]]
   report calcpg]
    [report ( r * (1 * sumx) )]
end

to-report process-shares                                                                                                  
  let avail-cpr cpr                                                                                             
  let sum-x 0
  let sum-wealth 0
  
  ;; sum up [x] investment decisions for group (will be used later to estimate wealth outcomes)
  foreach reverse members
  [
    set sum-x sum-x + [x] of ?
  ]
  ifelse game = 1 [ 
  foreach reverse members ; calculate in the order of upstream -> downstream
  [
    let member-index [index] of ?
    let member-a [alpha] of ?
    let member-b [beta] of ?
    let member-x [x] of ?
    ask ? [set success 0]
    let u-list [ ]
    let u-sum 0
    foreach possible-y
    [                                                                                                                    
      if cpr > 0 and (cpr * ?) <= avail-cpr * (1.01)                             ;; ad hoc method to deal with floating point problems
      [
        let share-remainder avail-cpr - ( cpr * ? )                              ;; remaining cpr for downstream after this share is taken
        let wealth-others ( ( group-size - 1 ) - ( sum-x - member-x ) + (cpr * (1 - ?))) / ( group-size - 1 )            ;; Average wealth of other agents              
        let wealth-self 1 - member-x + ? * cpr                                                                 
        set u-list fput ( calc-utility ( list wealth-others wealth-self ) member-a member-b ) u-list                        ;; Calculate the utility for this possible-y
        if first u-list > 0 [set u-sum u-sum + ( exp (first u-list * eta ))]
      ]
      
      if length u-list = 0
        [ set u-list fput 0 u-list ]
    ]                                                                                             
    
    ;; Calculate probability list for all possible-y
    let p-list get-plist u-list u-sum                                                   
    let rand 0
    let i 1
    let y-found? false
    set rand random-float 1                                                 
    let running-p 0
    while [ i <= length p-list and y-found? = false ]  ;; find which y is drawn
    [
      set running-p running-p + ( item ( length p-list - i ) p-list )
      ifelse ( rand < running-p )
        [ set y-found? true ]
        [ set i i + 1 ]
    ]                                                            
    ask ? [set share ( item ( i - 1 ) possible-y )]                                         
    set avail-cpr ( avail-cpr - ( [share] of ? * cpr ) )                  

    ask ? [set wealth ( ( 1 - x) + ( share * cpr ) )]                 
    ask ? [set wealth-avg-g ( wealth-avg-g + wealth )]         ;; just sum up wealth from each cycle.  we will average them out at the end of the generation
    set sum-wealth sum-wealth + [wealth] of ?
    if [wealth] of ? >= min-units [ ask ? [set success ( success + 1 ) ]] ;; how many agents in the cell do get at least their endownment
  ]][
    set sum-wealth 0
    foreach members [
      ask ? [set wealth ( 1 - x ) + 0.2 * cpr]
      set sum-wealth sum-wealth + (1 - [x] of ?) + 0.2 * cpr
      ask ? [set share 0.2]
      ifelse [wealth] of ? >= min-units [ask ? [set success 1]][ask ? [set success 0]]
    ]
  ]                                                                     
  report sum-wealth
end

to-report take-share [ total-cpr availcpr y-desired x-invested ]                
                                                                                
  ifelse ( y-desired * total-cpr ) < availcpr
    [ report y-desired ]
    [ 
      ifelse total-cpr > 0
        [ report availcpr / total-cpr ]
        [ report 0 ]
    ]
end

to-report calc-uwealth [ gsize mindex w ]                              
  let otherw 0                                                         
  let selfw 0
  let i 1                                                                                                                                        
  foreach reverse w
  [                                                                    
    ifelse i != mindex
      [ set otherw otherw + ? ]
      [ set selfw ? ]
    set i i + 1
  ]                                                                    
  set otherw ( otherw / (gsize - 1) )                                  
  report ( list otherw selfw )
end

to-report calc-utility [ wlist a b ] ;; calculate utility based on wealth of agent and average of other agents, and the alpha and beta of the agent                                  
  let member-wealth last wlist                                         
  let other-wealth first wlist                                         
  
  let alpha-coefficient ( member-wealth - other-wealth )
  if alpha-coefficient < 0 [ set alpha-coefficient 0 ]                 
  
  let beta-coefficient ( other-wealth - member-wealth )
  if beta-coefficient < 0 [ set beta-coefficient 0 ]                   

  report ( member-wealth - ( a * alpha-coefficient ) + ( b * beta-coefficient ) )     
end

to-report get-plist [ utils util-sum ] ;; calculate probabilities of making decisions based on expected utilities
  let plist [ ]
  foreach reverse utils
  [
    ifelse util-sum > 0
      [ ifelse ? > 0 [set plist fput ( (exp ( ? * eta )) / util-sum ) plist ][set plist fput 0 plist]]
      [ set plist fput ( 1  / length utils ) plist ]
  ]
  report plist
end

;; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 

to do-imitations
  let V 0
  let sum-V 0
  let V-list [ ]
  let i 0
  let p 0
  let p-list [ ]
  
  ask patches 
  [                                                                     
    let x-list [ ]                                                                                                        ;; list of xs from last time step
    let y-list [ ]                                                                                                        ;; list of shares from last time step
    let sum-x 0
      
    foreach reverse members                                                                                               ;; generate current x and y list for agents in patch.  Will be used later in estimating imitation usefulness
    [
      set x-list fput [x] of ? x-list
      ifelse cpr > 0
        [ set y-list fput [share] of ? y-list ]
        [ set y-list fput 0 y-list ]                                             
    ]                                                                   

    let model 0
    let bool 0
    let in-group? false
    foreach reverse members 
    [                                                                   
      set sum-V 0
      set V-list [ ]  ;; list to store values
      set V 0
      
      ifelse random-float 1.0 >= m 
        [ set in-group? true ]
        [ set in-group? false ]
      
      set i 1
      while [ i <= group-size ]                                                                                           ;; first calculate values for position comparison
      [
        ifelse in-group? and i = [index] of ?
        [ 
          set V-list fput 0 V-list                                                                                        ;; because we will not compare an agent against itself, we place 0 in its place in the list of values
        ]
        [
          ;; calculate V for i'th position
          set V ( ( 1 - chi ) ^ abs( [index] of ? - i ) )
          set V-list fput V V-list                                                                                        ;; by fputting, values are stored in reverse order (v of first index is in last position of list; e.g. 5th index is stored at list 0, 1st index is list 4)
          set sum-V ( sum-V + V )
        ]
        set i i + 1
      ]                                                       
      
      set p-list [ ]                                                                                                      ;; now, with sum-V calculated we can generate the probability spread for all positions
      foreach reverse V-list
      [
        set p-list fput ( ? / sum-V ) p-list
      ]                                                       
      
      set i 1                                                                                                             ;; probabilities have been calculated, now determine which index to compare against
      let index-found? false
      let choice random-float 1
      let running-prob 0
      
      while [ i <= group-size and index-found? = false ]
      [
        set running-prob running-prob + item ( group-size - i ) p-list
        
        ifelse ( choice < running-prob )
        [ set index-found? true ]
        [ set i i + 1 ]
      ]                                                       
    
                                                                                              ;; i should now be the index of the agent to be imitated
      ifelse in-group?                                                                         ; if random-float is = or over the mixing rate (default: 0.01)
      [                                                                                        ; then, run comparison on against another agent in-group
        set model item ( group-size - i ) members             
      ]
      [                                                                                        ; otherwise, match current agent with a random agent possessing index i anywhere in system (all patches)
        set model one-of ( turtle-set ( [members] of ( one-of neighbors ) ) ) with [ index = i ]  
      ]
      
      
 ;; estimate new wealth values based upon model's strategy
      let member-index [index] of ?
      let e-sum-x 0
      set i group-size
      foreach x-list
      [
        if i != member-index
        [
          set e-sum-x e-sum-x + ?
        ]
        set i i - 1
      ]
      set e-sum-x e-sum-x + [x] of model                      
      let e-cpr ( calc-cpr e-sum-x cpr-r cpr-gamma group-size game )     
      
      let avail-cpr e-cpr                                                
      let e-share 0
      set i 1
      while [ i < member-index ]
      [
        set e-share ( take-share e-cpr avail-cpr item ( group-size - i ) y-list item (group-size - i) x-list )   
        set avail-cpr ( avail-cpr - ( e-share * e-cpr ) )              
        set i i + 1
      ]
      
      set e-share ( take-share e-cpr avail-cpr [share] of model [x] of model )  
      let e-wealth ( ( 1 - [x] of model ) + ( e-share * e-cpr ) )              
                                                                               
      if ((e-wealth + [wealth-avg-g] of ?) ) * random-float 1 > (( [wealth-avg-g] of ?) )
      [             
        ask ? [set alpha ( [alpha] of model + random-normal 0 mu ) ]                             ; current agent imitates other agent (with added noise)
        if [alpha] of ? < [beta] of ? [ ask ? [set alpha beta]]
        if [alpha] of ? > 1 [ ask ? [set alpha 1 ]]
        
        ask ? [set beta ( [beta] of model + random-normal 0 mu ) ]
        if [beta] of ? < regard-floor [ ask ? [set beta regard-floor]]
        if [beta] of ? > [alpha] of ? [ ask ? [set beta alpha]]
        
      ]
    ]
  ]
end

to do-conflict                                                                        ;; All groups are randomly paired off so that every participates in a conflict once and only once during a given round. checks which groups may have a conflict and which group wins and takes the place of the losing group
  let coop-diff 0                                                                     ;; difference in cooperation rates between warring groups
  
  ask patches 
  [
    let opponent self
    let winner self
    let loser self
    
    if ( (random-float 1.0 < ex) and (no-war? = true) ) 
    [                                                                                 ;; If current patch hasn't already been attacked and random-float < ex (default: < 1.5% chance), current patch will attack another random patch
      set no-war? false
      set opponent one-of neighbors with [ no-war? = true ]                           ;; current patch will attack another random patch which has not already been at war this round
      ask opponent [set no-war? false]
      
      let survivors 0
      foreach members
      [
        set survivors survivors + [success] of ?
      ]
      set survivors ( survivors / ( generation-cycle * group-size ) )                 ;; average number of successful agents per cycle
      let fitness-self ( pwealth * survivors )
      
      set survivors 0
      ask opponent
      [
        foreach members
        [
          set survivors survivors + [success] of ?
        ]
        set survivors ( survivors / ( generation-cycle * group-size ) )
      ]
      let fitness-opponent ( [pwealth] of opponent * survivors )
      
      set coop-diff ( fitness-opponent - fitness-self )                               ;; calculate the difference in wealth between patches
      
      ifelse random-float 1.0 < ( 0.5 * ( 1 + coop-diff ) )                           ;; random chance is involved in victory, such that if each patch has an equal wealth there is a 50% chance of victory for a given side
      [                                                                               ;; opponent wins - members of current patch are replaced by members of the opponent
          set winner opponent
          set loser self
      ]
      [                                                                               ;; current patch wins - members of opponent are replaced by the members of the current patch
          set winner self
          set loser opponent
      ]
      
      let i 0
      while [ i < group-size ] 
      [                                                                               ;; losing agents are replaced by winning agents
        ask (item i [members] of loser) [
          set alpha [alpha] of (item i [members] of winner)
          set beta [beta] of (item i [members] of winner)
          set x [x] of (item i [members] of winner)
          set share [share] of (item i [members] of winner)
        ]
        set i i + 1
      ]
    ]
  ]
  ask patches [ set no-war? true ]
end

to do-mutations ; mutations which represents errors in inherenting information from parent agents
  ask agents [
    if random-float 1 <= mu 
    [
      set alpha ( alpha + random-normal 0 .01 )
      if alpha < beta [ set alpha beta ]
      if alpha < regard-floor [set alpha regard-floor]
      if alpha > 1 [ set alpha 1 ]
    ]
    if random-float 1 <= mu 
    [
      set beta ( beta + random-normal 0 .01 )
      if beta < regard-floor [ set beta regard-floor ]
      if beta > alpha [set beta alpha]
      if beta > 1 [ set beta 1 ]
    ]
  ]
end

;; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 

to setup-plot
  set-current-plot "avg-a"
  set-plot-y-range 0 1
  set-current-plot "avg-b"
  set-plot-y-range 0 1
  set-current-plot "avg-share"
  set-plot-y-range 0 1
  set-current-plot "avg-wealth"
  set-plot-y-range 0 precision max-wealth 1
  set-current-plot "avg-cpr"
  set-plot-y-range 0 precision max-cpr 1
  
  set-current-plot "1-avg-share"
  set-plot-y-range 0 1
  set-current-plot "2-avg-share"
  set-plot-y-range 0 1
  set-current-plot "3-avg-share"
  set-plot-y-range 0 1
  set-current-plot "4-avg-share"
  set-plot-y-range 0 1
  set-current-plot "5-avg-share"
  set-plot-y-range 0 1

  set-current-plot "1-avg-x"
  set-plot-y-range 0 1
  set-current-plot "2-avg-x"
  set-plot-y-range 0 1
  set-current-plot "3-avg-x"
  set-plot-y-range 0 1
  set-current-plot "4-avg-x"
  set-plot-y-range 0 1
  set-current-plot "5-avg-x"
  set-plot-y-range 0 1
end

to calculate-stats
  let i 0
  
  set avg-a 0
  set avg-b 0
  set avg-x 0
  set avg-share 0
  set avg-wealth 0
  set avg-cpr 0
  set avg-success 0

  ;set avg-gini-x 0
  ;set avg-gini-share 0
  
  set first-share 0
  set second-share 0
  set mid-share 0
  set second-last-share 0
  set last-share 0
  
  set first-x 0
  set second-x 0
  set mid-x 0
  set second-last-x 0
  set last-x 0
  
  set first-a 0
  set second-a 0
  set mid-a 0
  set second-last-a 0
  set last-a 0
  
  set first-b 0
  set second-b 0
  set mid-b 0
  set second-last-b 0
  set last-b 0
  
  ask patches 
  [
    set i 0
    set avg-cpr avg-cpr + cpr
    
    foreach reverse members                                                     ;; sort agents according to index
    [
      set avg-a avg-a + [alpha] of ? 
      set avg-b avg-b + [beta] of ?
      set avg-x avg-x + [x] of ?
      set avg-share avg-share + [share] of ?
      set avg-wealth avg-wealth + [wealth] of ?
      set avg-success avg-success + [success] of ?
        
      if i = 0                                                                  ;; first agent in group
      [ 
        set first-share first-share + [share] of ?
        set first-x first-x + [x] of ?
        set first-a first-a + [alpha] of ?
        set first-b first-b + [beta] of ?
      ]
      if i = 1                                                                  ;; second agent in group
      [ 
        set second-share second-share + [share] of ?  
        set second-x second-x + [x] of ?  
        set second-a second-a + [alpha] of ?
        set second-b second-b + [beta] of ?
      ]
      if i = round ( group-size / 2 )                                           ;; middle agent in group
      [ 
        set mid-share mid-share + [share] of ?  
        set mid-x mid-x + [x] of ?
        set mid-a mid-a + [alpha] of ?
        set mid-b mid-b + [beta] of ?
      ]
      if i = group-size - 2                                                     ;; second-to-last agent in group
      [ 
        set second-last-share second-last-share + [share] of ?  
        set second-last-x second-last-x + [x] of ?
        set second-last-a second-last-a + [alpha] of ?
        set second-last-b second-last-b + [beta] of ?
      ]
      if i = group-size - 1                                                     ;; last agent in group
      [ 
        set last-share last-share + [share] of ?  
        set last-x last-x + [x] of ?
        set last-a last-a + [alpha] of ?
        set last-b last-b + [beta] of ?
      ]
      set i i + 1
    ]
  ]
  
  set avg-a avg-a / total-population
  set avg-b avg-b / total-population
  set avg-x avg-x / total-population
  set avg-share avg-share / total-population
  set avg-wealth avg-wealth / num-groups
  set avg-cpr avg-cpr / num-groups
  set avg-success avg-success / ( total-population )
    
  set first-share first-share / num-groups
  set second-share second-share / num-groups
  set mid-share mid-share / num-groups
  set second-last-share second-last-share / num-groups
  set last-share last-share / num-groups
  
  set first-x first-x / num-groups
  set second-x second-x / num-groups
  set mid-x mid-x / num-groups
  set second-last-x second-last-x / num-groups
  set last-x last-x / num-groups
  
  set first-a first-a / num-groups
  set second-a second-a / num-groups
  set mid-a mid-a / num-groups
  set second-last-a second-last-a / num-groups
  set last-a last-a / num-groups
  
  set first-b first-b / num-groups
  set second-b second-b / num-groups
  set mid-b mid-b / num-groups
  set second-last-b second-last-b / num-groups
  set last-b last-b / num-groups
  
  if ticks > 2900 [
    set cum-a cum-a + 0.01 * avg-a
    set cum-b cum-b + 0.01 * avg-b
    set cum-x cum-x + 0.01 * avg-x
    set cum-share cum-share + 0.01 * avg-share
    set cum-wealth cum-wealth + 0.01 * avg-wealth
    set cum-cpr cum-cpr + 0.01 * avg-cpr
    set first-cum-share first-cum-share + 0.01 * first-share
    set second-cum-share second-cum-share + 0.01 * second-share
    set mid-cum-share mid-cum-share + 0.01 * mid-share
    set second-last-cum-share second-last-cum-share + 0.01 * second-last-share
    set last-cum-share last-cum-share + 0.01 * last-share
    set first-cum-x first-cum-x + 0.01 * first-x
    set second-cum-x second-cum-x + 0.01 * second-x
    set mid-cum-x mid-cum-x + 0.01 * mid-x
    set second-last-cum-x second-last-cum-x + 0.01 * second-last-x
    set last-cum-x last-cum-x + 0.01 * last-x
  ]
end

to calc-gini
  ;; calculate gini coefficients
  ask patches
  [
    set gini-x 0
    set gini-share 0
    let sum-gini-x 0
    let sum-gini-share 0
    let sum-x 0
    let sum-share 0
    let temp-gini 0
    let i 0
    let j 0
    
    foreach members
    [
      set sum-x sum-x + [x] of ?
      set sum-share sum-share + [share] of ?
    ]
    
    let help 0
    while [ i < ( group-size - 1 ) ]                                                      
    [
      set j i + 1
      let agentA item i members
      while [ j < group-size ]
      [
        let agentB item j members
        set temp-gini abs ( [x] of agentA - [x] of agentB )
        set sum-gini-x sum-gini-x + temp-gini
        set help help + 1
        
        set temp-gini abs ( [share] of agentA - [share] of agentB )
        set sum-gini-share sum-gini-share + temp-gini
        set j j + 1
      ]
      set i i + 1
    ]
    
    ifelse ( sum-x = 0 )
     [ set gini-x 0 ]                              
     [ set gini-x ( sum-gini-x / ( group-size * sum-x ) ) ]
     
    ifelse ( sum-share = 0 )
      [ set gini-share 0 ]                                      
      [ set gini-share sum-gini-share / ( group-size * sum-share ) ]
      
    set pginix pginix + gini-x                                         
    set pginishare pginishare + gini-share                             
  ]
end

to do-data-output
  file-type ticks file-type ","
  file-type min-units file-type ","
  file-type cpr-gamma file-type ","
  file-type cpr-r file-type ","
  file-type eta file-type ","
  file-type ex file-type ","
  file-type generation-cycle file-type ","
  file-type group-size file-type ","
  file-type mu file-type ","
  file-print regard-floor
  file-flush
end

to do-plot
  set-current-plot "avg-a"
  plot avg-a
  set-current-plot "avg-b"
  plot avg-b
  set-current-plot "avg-share"
  plot avg-share
  set-current-plot "avg-x"
  plot avg-x
  set-current-plot "avg-wealth"
  plot avg-wealth
  set-current-plot "avg-cpr"
  plot avg-cpr
  set-current-plot "success-factor"
  plot avg-success
  set-current-plot "avg-gini-x"
  plot avg-gini-x
  set-current-plot "avg-gini-share"
  plot avg-gini-share

  set-current-plot "1-avg-share"
  plot first-share
  set-current-plot "2-avg-share"
  plot second-share
  set-current-plot "3-avg-share"
  plot mid-share
  set-current-plot "4-avg-share"
  plot second-last-share
  set-current-plot "5-avg-share"
  plot last-share

  set-current-plot "1-avg-x"
  plot first-x
  set-current-plot "2-avg-x"
  plot second-x
  set-current-plot "3-avg-x"
  plot mid-x
  set-current-plot "4-avg-x"
  plot second-last-x
  set-current-plot "5-avg-x"
  plot last-x
  
  set-current-plot "hista"
  set-plot-x-range -1 1.1
  set-plot-y-range 0 count turtles
  set-histogram-num-bars 21
  histogram [alpha] of turtles  
  
  set-current-plot "histb"
  set-plot-x-range -1 1.1
  set-plot-y-range 0 count turtles
  set-histogram-num-bars 21
  histogram [beta] of turtles  

  ask patches                                       ;; color patches according to average investment levels
  [ 
    let fractionsuccess 0
    foreach members [
       set fractionsuccess fractionsuccess + [alpha] of ?
    ]
    set fractionsuccess fractionsuccess / 5.0
    set pcolor scale-color green cpr 0 10
  ]
end

to end-run
  file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
963
75
1223
356
-1
-1
25.0
1
10
1
1
1
0
1
1
1
0
9
0
9
1
1
1
ticks

BUTTON
5
11
60
44
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
64
11
137
44
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
4
85
164
205
avg-a
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"frcont" 1.0 0 -13345367 true

PLOT
4
211
164
331
avg-b
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"frpunish" 1.0 0 -13345367 true

SLIDER
415
46
544
79
m
m
0
0.1
0.0010
0.001
1
NIL
HORIZONTAL

SLIDER
546
10
675
43
mu
mu
0
0.1
0.01
0.01
1
NIL
HORIZONTAL

SLIDER
547
46
676
79
ex
ex
0
0.1
0.015
0.0050
1
NIL
HORIZONTAL

PLOT
168
211
328
331
avg-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
168
85
328
205
avg-wealth
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
8
416
168
536
1-avg-share
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
172
416
332
536
2-avg-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
502
416
662
536
4-avg-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
667
417
827
537
5-avg-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
9
592
169
712
1-avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
174
593
334
713
2-avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
503
593
663
713
4-avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
668
593
828
713
5-avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
497
208
657
328
avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

SLIDER
678
10
807
43
cpr-gamma
cpr-gamma
1
20
4
1
1
NIL
HORIZONTAL

SLIDER
678
46
807
79
cpr-r
cpr-r
1
10
2
1
1
NIL
HORIZONTAL

SLIDER
414
10
543
43
group-size
group-size
2
29
5
1
1
NIL
HORIZONTAL

TEXTBOX
25
344
175
362
1st Agents in Group
13
0.0
1

TEXTBOX
210
344
308
362
2nd Agents
13
0.0
1

TEXTBOX
522
344
672
362
2nd-Last Agents
13
0.0
1

TEXTBOX
706
344
794
362
Last Agents
13
0.0
1

PLOT
337
416
497
536
3-avg-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
338
593
498
713
3-avg-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

TEXTBOX
369
345
466
363
Middle Agents
13
0.0
1

SLIDER
808
10
937
43
generation-cycle
generation-cycle
1
20
10
1
1
NIL
HORIZONTAL

PLOT
333
210
493
330
avg-cpr
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

SLIDER
159
46
278
79
eta
eta
0
10
9.99
0.01
1
NIL
HORIZONTAL

MONITOR
8
368
168
413
first-avg-share
first-share
2
1
11

MONITOR
172
368
332
413
second-avg-share
second-share
2
1
11

MONITOR
337
368
497
413
NIL
mid-share
2
1
11

MONITOR
502
369
662
414
NIL
second-last-share
2
1
11

MONITOR
666
369
827
414
NIL
last-share
2
1
11

MONITOR
9
545
169
590
NIL
first-x
2
1
11

MONITOR
174
546
334
591
NIL
second-x
2
1
11

MONITOR
338
546
498
591
NIL
mid-x
2
1
11

MONITOR
502
546
663
591
NIL
second-last-x
2
1
11

MONITOR
668
546
828
591
NIL
last-x
2
1
11

SLIDER
809
45
938
78
min-units
min-units
0
4
1
0.01
1
NIL
HORIZONTAL

SLIDER
160
10
277
43
regard-floor
regard-floor
-1
0
-1
1
1
NIL
HORIZONTAL

PLOT
331
85
491
205
avg-gini-x
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
658
88
818
208
avg-gini-share
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

SWITCH
282
46
412
79
enable-plots?
enable-plots?
0
1
-1000

BUTTON
64
46
138
79
Close File
end-run
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
494
86
654
206
success-factor
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

SWITCH
282
11
411
44
output-file?
output-file?
1
1
-1000

BUTTON
4
47
67
80
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
937
10
1069
43
freqassym
freqassym
0
10
0
1
1
NIL
HORIZONTAL

PLOT
841
367
1069
541
hista
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

PLOT
839
547
1071
712
histb
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

INPUTBOX
1070
13
1223
73
output-filename
null
1
0
String

@#$#@#$#@
This is a Netlogo implementation of the model described in Marco A. Janssen and Nathan D. Rollins on "Evolution of cooperation in asymmetric commons dilemmas" which is submitted for publication.

The model is implemented Marco A. Janssen and Nathan D. Rollins, Arizona State University, August 2010. Copyright (C) 2010 M.A. Janssen and N.D. Rollins

This program is free software; you can redistribute it and/or modify it under the 
terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="3000"/>
    <metric>cum-a</metric>
    <metric>cum-b</metric>
    <metric>cum-x</metric>
    <metric>cum-y</metric>
    <metric>cum-wealth</metric>
    <metric>cum-cpr</metric>
    <metric>first-cum-share</metric>
    <metric>second-cum-share</metric>
    <metric>mid-cum-share</metric>
    <metric>second-last-cum-share</metric>
    <metric>last-cum-share</metric>
    <metric>first-cum-x</metric>
    <metric>second-cum-x</metric>
    <metric>mid-cum-x</metric>
    <metric>second-last-cum-x</metric>
    <metric>last-cum-x</metric>
    <enumeratedValueSet variable="output-filename">
      <value value="&quot;null&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="m">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freqassym">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="regard-floor">
      <value value="-1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-units">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-plots?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-size">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="generation-cycle">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="output-file?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ex">
      <value value="0.015"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mu">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eta">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cpr-gamma">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cpr-r">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
